@@ -8,6 +8,7 @@ class CMTTTestCase(unittest.TestCase):
     self.list_dataset_keys = list_dataset_keys
     self.WordT = WordTokenizer()
     self.WordpieceT = Wordpiece_tokenizer()
+    self.WhitespaceT = WhitespaceTokenizer()
 
   def test_data_load_url_1(self):
     """Test data load_url function 1"""
@@ -28,7 +29,7 @@ class CMTTTestCase(unittest.TestCase):
   def test_whitespace_tokenize(self):
     """Test whitespace tokenize function"""
     text = "Hello world! This a python code. Let's activate"
-    result = whitespace_tokenize(text)
+    result = self.WhitespaceT.tokenize(text)
     self.assertEqual(len(result), 8)
   
   def test_word_tokenize(self):
@@ -41,7 +42,7 @@ class CMTTTestCase(unittest.TestCase):
     """Test wordpiece tokenize function"""
     text = "This Python interpreter is in a conda environment, but the environment has not been activated.  Libraries may fail to load.  To activate this environment"
     result = self.WordpieceT.tokenize(text)
-    self.assertEqual(len(result), 30)
+    self.assertEqual(len(result), 32)
 
   def test_search(self):
     """Test wordpiece tokenize function"""
